"""Application schemas package."""

{% if advanced_alchemy %}
from schemas.users import CreateUser, ReadUser, UpdateUser

__all__ = [
    "CreateUser",
    "ReadUser",
    "UpdateUser",
]
{% else %}
__all__ = []
{% endif %}
