[project]
name = "{{ project_slug }}"
version = "0.1.0"
description = "A Litestar application"
readme = "README.md"
requires-python = ">=3.13"
dependencies = [
    "litestar[standard]>=2.16.0",
    "python-dotenv>=1.1.0",
{% if advanced_alchemy %}
    "advanced-alchemy>=1.8.2",
{% if database.value == "PostgreSQL" %}
    "psycopg[binary,pool]>=3.3.2",
{% elif database.value == "SQLite" %}
    "aiosqlite>=0.22.1",
{% elif database.value == "MySQL" %}
    "asyncmy>=0.2.10",
{% endif %}
{% endif %}
{% if litestar_vite %}
    "litestar-vite>=0.16.4",
{% endif %}
]

[tool.ruff]
line-length = 120
target-version = "py313"
lint.ignore = [
    "CPY001",    # Missing copyright notice
    "PLC0415",   # Import outside top level
    "PLR0911",   # Too many return statements
]

[dependency-groups]
dev = ["pre-commit>=4.5.1", "ruff>=0.14.13", "ty>=0.0.12"]
