# Byte-compiled / optimized / DLL files
__pycache__/
*.py[cod]
*$py.class

# C extensions
*.so

# Distribution / packaging
.Python
build/
develop-eggs/
dist/
downloads/
eggs/
.eggs/
lib64/
parts/
sdist/
var/
wheels/
*.egg-info/
.installed.cfg
*.egg
node_modules/

# Virtual environments
.venv/
venv/
ENV/
env/

# IDE
.idea/
.vscode/
*.swp
*.swo
*~

# Environment variables
.env
.env.local
.env.*.local

# Testing
.coverage
htmlcov/
.pytest_cache/
.mypy_cache/

# Logs
*.log
logs/

# Database
*.db
*.sqlite
*.sqlite3

# OS files
.DS_Store
Thumbs.db
