"""Application library utilities."""

{% if advanced_alchemy %}
from lib.dependencies import provide_user_service
from lib.services import UserService
from lib.utils import exception_handler

__all__ = [
    "UserService",
    "exception_handler",
    "provide_user_service",
]
{% else %}
__all__ = []
{% endif %}
