"""Application entry point."""

import uvicorn

from config import settings


def main() -> None:
    """Run the application."""
    uvicorn.run(
        "app:app",
        host=settings.HOST,
        port=settings.PORT,
        reload=settings.DEBUG,
    )


if __name__ == "__main__":
    main()
