# {{ project_name }}

A Litestar application generated with [litestar-start](https://github.com/Harshal6927/litestar-start).

## Features

- ⚡ **Litestar** - High-performance ASGI framework
{% if advanced_alchemy %}
- 🗄️ **AdvancedAlchemy** - Async ORM with {{ database.value }}
{% endif %}
{% if docker %}
- 🐳 **Docker** - Containerized deployment
{% endif %}

## Getting Started

### Prerequisites

- Python 3.13+
- [uv](https://docs.astral.sh/uv/) (recommended) or pip
{% if docker_infra %}
- Docker & Docker Compose (for local database)
{% endif %}

### Installation

```bash
# Clone the repository
cd {{ project_slug }}

# Install dependencies
uv sync

# Copy environment variables
cp .env.example .env
```

{% if docker_infra %}
### Start Infrastructure

```bash
# Start database container
docker compose -f docker-compose.infra.yml up -d
```

{% endif %}
### Run the Application

```bash
# Development mode with auto-reload
litestar run --reload

# Or using uvicorn directly
uvicorn app.main:app --reload
```

The API will be available at http://localhost:8000

### API Documentation

- Swagger UI: http://localhost:8000/schema
- ReDoc: http://localhost:8000/schema/redoc

## Project Structure

```
{{ project_slug }}/
├── app/
│   ├── __init__.py
│   ├── __main__.py
│   ├── config.py
│   └── main.py
{% if advanced_alchemy %}
├── models/
│   ├── __init__.py
│   └── config.py
{% endif %}
├── .env.example
├── .gitignore
├── pyproject.toml
└── README.md
```

## License

MIT
